@@ -280,10 +280,11 @@ def evaluate_experiment(
             client=client, experiment_name=experiment_name
         )
 
+    dataset_ = client.get_dataset(name=experiment.dataset_name)
+
     test_cases = rest_operations.get_experiment_test_cases(
-        client=client,
-        experiment_id=experiment.id,
-        dataset_id=experiment.dataset_id,
+        experiment_=experiment,
+        dataset_=dataset_,
         scoring_key_mapping=scoring_key_mapping,
     )
     first_trace_id = test_cases[0].trace_id
@@ -315,13 +316,11 @@ def evaluate_experiment(
     total_time = time.time() - start_time
 
     if verbose >= 1:
-        report.display_experiment_results(
-            experiment.dataset_name, total_time, test_results
-        )
+        report.display_experiment_results(dataset_.name, total_time, test_results)
 
     experiment_url = url_helpers.get_experiment_url_by_id(
         experiment_id=experiment.id,
-        dataset_id=experiment.dataset_id,
+        dataset_id=dataset_.id,
         url_override=client.config.url_override,
     )
 
@@ -330,7 +329,7 @@ def evaluate_experiment(
     _try_notifying_about_experiment_completion(experiment)
 
     evaluation_result_ = evaluation_result.EvaluationResult(
-        dataset_id=experiment.dataset_id,
+        dataset_id=dataset_.id,
         experiment_id=experiment.id,
         experiment_name=experiment.name,
         test_results=test_results,
@@ -340,7 +339,7 @@ def evaluate_experiment(
 
     if verbose >= 2:
         report.display_evaluation_scores_statistics(
-            dataset_name=experiment.dataset_name,
+            dataset_name=dataset_.name,
             evaluation_results=evaluation_result_,
         )
 
@@ -355,7 +354,10 @@ def _build_prompt_evaluation_task(
         {
             "vision": ModelCapabilities.supports_vision(
                 getattr(model, "model_name", None)
-            )
+            ),
+            "video": ModelCapabilities.supports_video(
+                getattr(model, "model_name", None)
+            ),
         },
     )
     chat_prompt_template = ChatPromptTemplate(messages=messages)
