@@ -32,6 +32,8 @@ class AnswerRelevance(base_metric.BaseMetric):
         require_context: if set to False, execution in no-context mode is allowed. Default is True.
         track: Whether to track the metric. Defaults to True.
         project_name: Optional project name to track the metric in for the cases when there are no parent span/trace to inherit project name from.
+        seed: Optional seed value for reproducible model generation. If provided, this seed will be passed to the model for deterministic outputs.
+        temperature: Optional temperature value for model generation. If provided, this temperature will be passed to the model. If not provided, the model's default temperature will be used.
 
     Example:
         >>> from opik.evaluation.metrics import AnswerRelevance
@@ -56,6 +58,8 @@ class AnswerRelevance(base_metric.BaseMetric):
         require_context: bool = True,
         track: bool = True,
         project_name: Optional[str] = None,
+        seed: Optional[int] = None,
+        temperature: Optional[float] = None,
     ):
         super().__init__(
             name=name,
@@ -63,19 +67,28 @@ class AnswerRelevance(base_metric.BaseMetric):
             project_name=project_name,
         )
         self._require_context = require_context
-        self._init_model(model)
+        self._seed = seed
+        self._init_model(model, temperature=temperature)
         self._init_few_shot_examples(
             few_shot_examples_with_context=few_shot_examples,
             few_shot_examples_no_context=few_shot_examples_no_context,
         )
 
     def _init_model(
-        self, model: Optional[Union[str, base_model.OpikBaseModel]]
+        self,
+        model: Optional[Union[str, base_model.OpikBaseModel]],
+        temperature: Optional[float],
     ) -> None:
         if isinstance(model, base_model.OpikBaseModel):
             self._model = model
         else:
-            self._model = models_factory.get(model_name=model)
+            model_kwargs = {}
+            if temperature is not None:
+                model_kwargs["temperature"] = temperature
+            if self._seed is not None:
+                model_kwargs["seed"] = self._seed
+
+            self._model = models_factory.get(model_name=model, **model_kwargs)
 
     def _init_few_shot_examples(
         self,
@@ -124,7 +137,8 @@ class AnswerRelevance(base_metric.BaseMetric):
         )
 
         model_output = self._model.generate_string(
-            input=llm_query, response_format=AnswerRelevanceResponseFormat
+            input=llm_query,
+            response_format=AnswerRelevanceResponseFormat,
         )
         return parser.parse_model_output(content=model_output, name=self.name)
 
@@ -154,7 +168,8 @@ class AnswerRelevance(base_metric.BaseMetric):
             input=input, output=output, context=context
         )
         model_output = await self._model.agenerate_string(
-            input=llm_query, response_format=AnswerRelevanceResponseFormat
+            input=llm_query,
+            response_format=AnswerRelevanceResponseFormat,
         )
 
         return parser.parse_model_output(content=model_output, name=self.name)
